@@ -1,3 +1,11 @@
+"""
+sentry.client.log
+~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 from sentry.client.base import SentryClient
 
 import logging
